@echo on
set "CONDA_BUILD=1"
set "PYTHONNOUSERSITE=1"
set "CONDA_DEFAULT_ENV=C:\ci\pymongo_1613850059737\_h_env"
set "ARCH=32"
set "PREFIX=C:\ci\pymongo_1613850059737\_h_env"
set "BUILD_PREFIX=C:\ci\pymongo_1613850059737\_build_env"
set "SYS_PREFIX=C:\ci\containers\000034355m0\tmp\build\80754af9\build_env"
set "SYS_PYTHON=C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\python.exe"
set "SUBDIR=win-32"
set "build_platform=win-64"
set "SRC_DIR=C:\ci\pymongo_1613850059737\work"
set "ROOT=C:\ci\containers\000034355m0\tmp\build\80754af9\build_env"
set "CONDA_PY=39"
set "PY3K=1"
set "PY_VER=3.9"
set "STDLIB_DIR=C:\ci\pymongo_1613850059737\_h_env\Lib"
set "SP_DIR=C:\ci\pymongo_1613850059737\_h_env\Lib\site-packages"
set "PYTHON=C:\ci\pymongo_1613850059737\_h_env\python.exe"
set "NPY_VER=1.16"
set "CONDA_NPY=1.16"
set "NPY_DISTUTILS_APPEND_FLAGS=1"
set "PERL_VER=5.26"
set "CONDA_PERL=5.26"
set "LUA_VER=5"
set "CONDA_LUA=5"
set "R_VER=3.5"
set "CONDA_R=3.5"
set "PKG_NAME=pymongo"
set "PKG_VERSION=3.11.3"
set "PKG_BUILDNUM=0"
set "PKG_BUILD_STRING=placeholder"
set "PKG_HASH=1234567"
set "RECIPE_DIR=C:\ci\containers\000034355m0\tmp\build\80754af9\combined_recipe"
set "CPU_COUNT=6"
set "SHLIB_EXT=.dll"
set "PATH=C:\ci\pymongo_1613850059737\_build_env;C:\ci\pymongo_1613850059737\_build_env\Library\mingw-w64\bin;C:\ci\pymongo_1613850059737\_build_env\Library\usr\bin;;C:\ci\pymongo_1613850059737\_build_env\Library\bin;C:\ci\pymongo_1613850059737\_build_env\Scripts;C:\ci\pymongo_1613850059737\_build_env\Scripts;C:\ci\pymongo_1613850059737\_h_env;C:\ci\pymongo_1613850059737\_h_env\Library\mingw-w64\bin;C:\ci\pymongo_1613850059737\_h_env\Library\usr\bin;;C:\ci\pymongo_1613850059737\_h_env\Library\bin;C:\ci\pymongo_1613850059737\_h_env\Scripts;C:\ci\pymongo_1613850059737\_h_env\Scripts;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Library\mingw-w64\bin;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Library\usr\bin;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Library\bin;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Scripts;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\bin;C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\condabin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v10.1\bin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v10.1\libnvvp;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v10.0\bin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v10.0\libnvvp;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v9.2\bin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v9.2\libnvvp;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v9.0\bin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v9.0\libnvvp;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v8.0\bin;C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v8.0\libnvvp;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64_win\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32_win\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64_win\compiler;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32_win\compiler;C:\Windows\system32;C:\Windows;C:\Windows\System32\Wbem;C:\Windows\System32\WindowsPowerShell\v1.0;C:\Windows\System32\OpenSSH;c:\Program Files (x86)\Microsoft SQL Server\90\Tools\binn;C:\Users\builder\.dnx\bin;C:\Program Files\Microsoft DNX\Dnvm;C:\Program Files\Microsoft SQL Server\130\Tools\Binn;C:\Program Files\Mercurial;C:\Program Files\PuTTY;C:\curl\bin;C:\git\mingw64\bin;C:\Program Files (x86)\7-Zip;.;C:\Program Files (x86)\NVIDIA Corporation\PhysX\Common;C:\Program Files\NVIDIA Corporation\Nsight Compute 2019.4.0;C:\Users\builder\AppData\Local\Microsoft\WindowsApps"
set "SCRIPTS=C:\ci\pymongo_1613850059737\_h_env\Scripts"
set "LIBRARY_PREFIX=C:\ci\pymongo_1613850059737\_h_env\Library"
set "LIBRARY_BIN=C:\ci\pymongo_1613850059737\_h_env\Library\bin"
set "LIBRARY_INC=C:\ci\pymongo_1613850059737\_h_env\Library\include"
set "LIBRARY_LIB=C:\ci\pymongo_1613850059737\_h_env\Library\lib"
set "CYGWIN_PREFIX=/cygdrive/c/ci/pymongo_1613850059737/_h_env"
set "ALLUSERSPROFILE=C:\ProgramData"
set "APPDATA=C:\Users\builder\AppData\Roaming"
set "CommonProgramFiles=C:\Program Files\Common Files"
set "CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files"
set "CommonProgramW6432=C:\Program Files\Common Files"
set "COMPUTERNAME=COLO-WWGPU-02"
set "ComSpec=C:\Windows\system32\cmd.exe"
set "LOCALAPPDATA=C:\Users\builder\AppData\Local"
set "NUMBER_OF_PROCESSORS=6"
set "PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC"
set "ProgramData=C:\ProgramData"
set "ProgramFiles=C:\Program Files"
set "ProgramFiles(x86)=C:\Program Files (x86)"
set "ProgramW6432=C:\Program Files"
set "PROMPT=(base) $P$G"
set "PSModulePath=C:\Program Files\WindowsPowerShell\Modules;C:\Windows\system32\WindowsPowerShell\v1.0\Modules"
set "PUBLIC=C:\Users\Public"
set "SystemDrive=C:"
set "SystemRoot=C:\Windows"
set "TEMP=C:\Users\builder\AppData\Local\Temp"
set "TMP=C:\Users\builder\AppData\Local\Temp"
set "USERDOMAIN=COLO-WWGPU-02"
set "USERNAME=builder"
set "USERPROFILE=C:\Users\builder"
set "windir=C:\Windows"
set "PROCESSOR_ARCHITECTURE=AMD64"
set "PROCESSOR_IDENTIFIER=Intel64 Family 6 Model 79 Stepping 1, GenuineIntel"
set "BUILD=i386-pc-windows-19.0.0"
set "VS100COMNTOOLS=C:\Program Files (x86)\Microsoft Visual Studio 10.0\Common7\Tools\"
set "VS140COMNTOOLS=C:\Program Files (x86)\Microsoft Visual Studio 14.0\Common7\Tools\"
set "VS2017INSTALLDIR=C:\Program Files (x86)\Microsoft Visual Studio\2017\Professional"
set "VS90COMNTOOLS=C:\Program Files (x86)\Microsoft Visual Studio 9.0\Common7\Tools\"
set "ignore_build_only_deps={'python', 'numpy'}"
set "extend_keys={'ignore_version', 'ignore_build_only_deps', 'extend_keys', 'pin_run_as_build'}"
set "zip_keys=[['vc', 'c_compiler', 'cxx_compiler', 'fortran_compiler_version', 'python', 'nodejs', 'geos']]"
set "pin_run_as_build=OrderedDict([('python', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('libboost', {'max_pin': 'x.x.x'})])"
set "libxml2=2.9"
set "gmp=6.1"
set "libgd=2.2.5"
set "boost_cpp=1.73"
set "hdf5=1.10.6"
set "libwebp=1.0.0"
set "fontconfig=2.13"
set "icu=58"
set "gnu=2.12.2"
set "libnetcdf=4.6"
set "cross_compiler_target_platform=win-32"
set "mpfr=4"
set "cran_mirror=https://mran.microsoft.com/snapshot/2018-01-01"
set "apr=1.6.3"
set "readline=8.0"
set "pixman=0.30"
set "rust_compiler=rust"
set "serf=1.3.9"
set "noarch_python=python"
set "libgdal=3.0"
set "python_impl=cpython"
set "boost=1.73"
set "cpu_optimization_target=nocona"
set "openblas=0.3.3"
set "bzip2=1.0"
set "hdf4=4.2"
set "openssl=1.1.1"
set "openjpeg=2.3"
set "macos_min_version=10.9"
set "xz=5"
set "gstreamer=1.14"
set "proj4=5.2.0"
set "proj=6.2.1"
set "m2w64_cxx_compiler=m2w64-toolchain"
set "libkml=1.3"
set "hdfeos2=2.20"
set "qtwebkit=true"
set "harfbuzz=2.4"
set "sqlite=3"
set "cairo=1.14"
set "blas_impl=mkl"
set "jpeg=9"
set "fortran_compiler=intel-fortran"
set "glib=2"
set "VERBOSE_AT=V=1"
set "cyrus_sasl=2.1.26"
set "libtiff=4.1"
set "libdap4=3.19"
set "freetype=2.10"
set "llvm_variant=llvm"
set "python_implementation=cpython"
set "zlib=1.2"
set "libprotobuf=3.11.2"
set "libpng=1.6"
set "MACOSX_DEPLOYMENT_TARGET=10.9"
set "r_implementation=r-base"
set "mkl=2019"
set "giflib=5"
set "macos_machine=x86_64-apple-darwin13.4.0"
set "m2w64_c_compiler=m2w64-toolchain"
set "libffi=3.2.1"
set "rust_compiler_version=1.46.0"
set "VERBOSE_CM=VERBOSE=1"
set "dbus=1"
set "r_base=3.5"
set "lzo=2"
set "hdfeos5=5.1"
set "clang_variant=clang"
set "r_version=3.5.0"
set "target_platform=win-32"
set "expat=2.2"
set "tk=8.6"
set "m2w64_fortran_compiler=m2w64-toolchain"
set "channel_targets=defaults"
set "gst_plugins_base=1.14"
set "g2clib=1.6"
set "libxslt=1.1"
set "libgsasl=1.8"
set "c_compiler=vs2017"
set "fortran_compiler_version=2019.0.0"
set "nodejs=8.12"
set "cxx_compiler=vs2017"
set "geos=3.8.0"
set "vc=14"
set "CONDA_BUILD_STATE=BUILD"
set "PIP_NO_BUILD_ISOLATION=False"
set "PIP_NO_DEPENDENCIES=True"
set "PIP_IGNORE_INSTALLED=True"
set "PIP_CACHE_DIR=C:\ci\pymongo_1613850059737\pip_cache"
set "PIP_NO_INDEX=True"
@echo on
set "INCLUDE=C:\ci\pymongo_1613850059737\_h_env\Library\include;%INCLUDE%"
set "LIB=C:\ci\pymongo_1613850059737\_h_env\Library\lib;%LIB%"
call "C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Scripts\..\condabin\conda_hook.bat"
call "C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Scripts\..\condabin\conda.bat" activate "C:\ci\pymongo_1613850059737\_h_env"
call "C:\ci\containers\000034355m0\tmp\build\80754af9\build_env\Scripts\..\condabin\conda.bat" activate --stack "C:\ci\pymongo_1613850059737\_build_env"
